Momoko
======

An asynchronous Psycopg2_ wrapper for Tornado_.

Documentation can be found at: http://momoko.61924.nl/

.. _Psycopg2: http://www.initd.org/psycopg/
.. _Tornado: http://www.tornadoweb.org/


Installation
------------

With pip::

    pip install momoko

Or manually::

    python setup.py install
